diff

Function diff 

pub fn diff(
    obj_store: &mut GitObjectStore,
    commits_table: &CommitsTable,
    base_commit_id: &str,
    head_commit_id: &str,
) -> Result<DiffResult, CommitError>
Compute the diff between two commits.

base is the earlier commit, head is the later commit. Returns triples added in head and triples removed from base.

Safety

This function replaces the live store contents by calling checkout() internally. Any uncommitted changes in obj_store will be lost. The store will contain the head commit’s state when this function returns. Callers should commit or save any in-progress work before calling diff().