restore_snapshot

Function restore_snapshot 

pub fn restore_snapshot(
    obj_store: &mut GitObjectStore,
    snapshot: &Snapshot,
) -> Result<(CommitsTable, RefsTable), RemoteError>
Restore git state from a Snapshot received over the wire.

Purely in-memory — no file I/O. Clears the local store and loads all namespace data from in-memory Parquet bytes. Commits and refs are deserialized from JSON strings.