Revert — create a new commit that undoes the changes from a target commit.
Unlike checkout, revert does not go back in time — it creates a NEW commit
on the current branch that applies the inverse of the target commit’s diff.
Enums
- Revert
Error - Errors from revert operations.
Functions
- revert
- Revert a commit by creating a new commit that undoes its changes.